@@ -9,23 +9,24 @@
 
 package org.gnu.gdk;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 /**
  *
  */
 public class EventDND extends Boxed 
 {
     /****************************************
-     * BEGINNING OF GENERATED CODE
+     * BEGINNING OF JNI CODE
      ****************************************/
-    native static final protected int getType (int obj);
-    native static final protected int getWindow (int obj);
-    native static final protected boolean getSendEvent (int obj);
-    native static final protected int getContext (int obj);
-    native static final protected int getTime (int obj);
-    native static final protected short getXRoot (int obj);
-    native static final protected short getYRoot (int obj);
+    native static final protected int getType (Handle obj);
+    native static final protected Handle getWindow (Handle obj);
+    native static final protected boolean getSendEvent (Handle obj);
+    native static final protected Handle getContext (Handle obj);
+    native static final protected int getTime (Handle obj);
+    native static final protected short getXRoot (Handle obj);
+    native static final protected short getYRoot (Handle obj);
     /****************************************
-     * END OF GENERATED CODE
+     * END OF JNI CODE
      ****************************************/
 }
 
