@@ -8,13 +8,26 @@
  */
 
 package org.gnu.gdk;
+
 import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
+
 /**
  *
  */
 public class Keymap extends GObject 
 {
+    public Keymap() {
+        super( getType() );
+    }
+
+    /**
+     * Retrieve the runtime type used by the GLib library.
+     */
+    public static org.gnu.glib.Type getType() {
+        return new org.gnu.glib.Type(gdk_keymap_get_type());
+    }
+
     /****************************************
      * BEGINNING OF JNI CODE
      ****************************************/
