@@ -9,13 +9,14 @@
 
 package org.gnu.gdk;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 public class Pango extends Boxed 
 {
     /****************************************
      * BEGINNING OF GENERATED CODE
      ****************************************/
-    native static final protected int gdk_pango_context_get ();
-    native static final protected void gdk_pango_context_set_colormap (int context, int colormap);
+    native static final protected Handle gdk_pango_context_get ();
+    native static final protected void gdk_pango_context_set_colormap (Handle context, Handle colormap);
     /****************************************
      * END OF GENERATED CODE
      ****************************************/
