@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -29,7 +30,7 @@ public class HBox extends Box
 		super(gtk_hbox_new (homogenous, spacing));
 	}
 	
-	public HBox(int handle) {
+	public HBox(Handle handle) {
 	    super(handle);
 	}
 
@@ -40,13 +41,9 @@ public class HBox extends Box
 		return new Type(gtk_hbox_get_type());
 	}
 
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
+
     native static final protected int gtk_hbox_get_type ();
-    native static final protected int gtk_hbox_new (boolean homogenous, int spacing);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected Handle gtk_hbox_new (boolean homogenous, int spacing);
+
 }
 
