@@ -9,6 +9,7 @@
 
 package org.gnu.gtk;
 
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -30,14 +31,10 @@ public class IMMulticontext extends IMContext
 		return new Type(gtk_im_multicontext_get_type());
 	}
 
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
+
     native static final protected int gtk_im_multicontext_get_type ();
-    native static final protected int gtk_im_multicontext_new ();
-    native static final protected void gtk_im_multicontext_append_menuitems (int context, int menushell);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+    native static final protected Handle gtk_im_multicontext_new ();
+    native static final protected void gtk_im_multicontext_append_menuitems (Handle context, Handle menushell);
+
 }
 
