@@ -9,6 +9,8 @@
 
 package org.gnu.gtk;
 
+import java.util.ArrayList;
+import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
@@ -88,6 +90,23 @@ public class Menu extends MenuShell {
 		return Menu.gtk_menu_get_title(getHandle());
 	}
 	
+    /**
+     * Returns a list of the menus which are attached to this
+     * widget.
+     */
+    public ArrayList getAttachedMenus() {
+        Handle[] handles = gtk_menu_get_for_attach_widget( getHandle() );
+        ArrayList ret = new ArrayList();
+        for( int i = 0; i < handles.length; i++ ) {
+            GObject obj = getGObjectFromHandle( handles[ i ] );
+            if ( obj == null ) {
+                ret.add( new Menu( handles[ i ] ) );
+            } else {
+                ret.add( (Menu)handles[ i ] );
+            }
+        }
+        return ret;
+    }
 
 	/**
 	 * Retrieve the runtime type used by the GLib library.
@@ -117,5 +136,6 @@ public class Menu extends MenuShell {
 	native static final protected void gtk_menu_set_screen(Handle menu, Handle screen);
 	native static final protected void gtk_menu_attach(Handle menu, Handle child, int left, int right, int top, int bottom);
 	native static final protected void gtk_menu_set_monitor(Handle menu, int monitorNum); 
+    native static final private Handle[] gtk_menu_get_for_attach_widget(Handle widget);
 
 }
