@@ -63,10 +63,41 @@ public class MessageDialog extends Dialog
 	    super(handle);
 	}
 
-	public void setMarkup(String markup) {
-		gtk_message_dialog_set_markup(getHandle(), markup);
-	}
+    /**
+     * Sets the text of the message dialog to be <tt>markup</tt>,
+     * which is marked up with the Pango text markup language.
+     *
+     * @param markup The markup string.
+     */
+    public void setMarkup(String markup) {
+        gtk_message_dialog_set_markup(getHandle(), markup);
+    }
 	
+    /**
+     * Sets the secondary text of the message dialog to be <tt>text</tt>.
+     * <p>
+     * Note that setting a secondary text makes the primary text
+     * become bold, unless you have provided explicit markup.
+     *
+     * @since 2.6
+     */
+    public void setSecondaryText( String text ) {
+        gtk_message_dialog_format_secondary_text( getHandle(), text );
+    }
+    /**
+     * Sets the secondary text of the message dialog to be
+     * <tt>markup</tt>, which is marked up with the Pango text markup
+     * language.
+     * <p>
+     * Note that setting a secondary text makes the primary text
+     * become bold, unless you have provided explicit markup.
+     *
+     * @since 2.6
+     */
+    public void setSecondaryMarkup( String markup ) {
+        gtk_message_dialog_format_secondary_markup( getHandle(), markup );
+    }
+
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -80,5 +111,9 @@ public class MessageDialog extends Dialog
     native static final protected Handle gtk_message_dialog_new_with_markup(Handle parent, int flags, int type, int buttons, String message);
     native static final protected void gtk_message_dialog_set_markup(Handle mdialog, String str);
 
+    // GTK 2.6 additions.
+    native static final private void gtk_message_dialog_format_secondary_text(Handle message_dialog, String message_format);
+    native static final private void gtk_message_dialog_format_secondary_markup(Handle message_dialog, String message_format);
+
 }
 
