@@ -61,10 +61,14 @@ public class TextBuffer extends GObject {
 	}
 
 	/**
-	 * Gets the number of characters in the buffer; note that characters and
-	 * bytes are not the same, you can't e.g. expect the contents of the buffer
-	 * in string form to be this many bytes long. The character count is cached,
-	 * so this function is very fast.
+ Gets the number of characters in the buffer. Note that
+	 * characters and
+ bytes are not the same. You can't expect
+	 * the contents of the buffer
+ in string form to be this many
+	 * bytes long. The character count is cached,
+ so this
+	 * function is very fast.
 	 * @return Number of characters in the buffer.
 	 */
 	public int getCharCount() {
@@ -591,7 +595,7 @@ public class TextBuffer extends GObject {
 	 * of the selection will be considered (users can't delete uneditable text).
 	 * @param interactive Whether the deletion is caused by user interaction
 	 * @param defaultEditable Whether the buffer is editable by default
-	 * @returns Whether there was a non-empty selection to delete
+	 * @return Whether there was a non-empty selection to delete
 	 */
 	public boolean deleteSelection(boolean interactive, boolean defaultEditable) {
 		return gtk_text_buffer_delete_selection(getHandle(), interactive, defaultEditable);
@@ -919,10 +923,14 @@ public class TextBuffer extends GObject {
 	}
 
 	/**
-	 * Creates a TextTag initialised for use in this TextBuffer.
+	 * Creates a TextTag initialised for use in this TextBuffer.  If
+	 * a TextTag already exists with this name null is returned.
 	 */
 	public TextTag createTag(String name) {
-		return new TextTag(create_tag(getHandle(), name));
+		Handle hndl = create_tag(getHandle(), name);
+		if (null == hndl)
+			return null;
+		return new TextTag(hndl);
 	}
 
 	native static final protected int gtk_text_buffer_get_type();
