@@ -8,12 +8,17 @@
  */
 
 package org.gnu.gtk;
+import org.gnu.gdk.Pixmap;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.pango.FontDescription;
 import org.gnu.pango.Scale;
+import org.gnu.pango.Stretch;
 import org.gnu.pango.Style;
+import org.gnu.pango.TabArray;
 import org.gnu.pango.Underline;
+import org.gnu.pango.Variant;
 import org.gnu.pango.Weight;
 /**
  * See the {@link TextBuffer} description for an overview of these classes.
@@ -22,6 +27,14 @@ import org.gnu.pango.Weight;
  */
 public class TextTag extends GObject 
 {
+	/**
+	 * Construct a new TextTag
+	 * @param name
+	 */
+	public TextTag(String name) {
+		super(gtk_text_tag_new(name));
+	}
+	
 	protected TextTag(Handle handle){
 		super(handle);
 	}
@@ -64,67 +77,254 @@ public class TextTag extends GObject
 		return gtk_text_tag_get_priority( getHandle() );
 	}
 
-	public void setSize(int size){
-		setIntProperty( getHandle(), "size", size * 1024);
-	}
-	public void setFamily( String family ){
-		setStringProperty( getHandle(), "family", family);
-	}
-	public void setForeground( String foreground ){
-		setStringProperty( getHandle(), "foreground", foreground );
-	}
+	/**
+	 * Sets the background color as a string.
+	 * @param background
+	 */
 	public void setBackground( String background ){
 		setStringProperty( getHandle(), "background", background );
 	}
-	public void setPixelsAboveLines( int setting ){
-		setIntProperty( getHandle(), "pixels_above_lines", setting );
+	
+	/**
+	 * Whether the background color fills the entire line height 
+	 * or only the height of the tagged characters.
+	 * @param fullHeight
+	 */
+	public void setBackgroundFullHeight( boolean fullHeight ) {
+		setBooleanProperty( getHandle(), "background-full-height", fullHeight );
 	}
-	public void setPixelsBelowLines( int setting ){
-		setIntProperty( getHandle(), "pixels_below_lines", setting );
-	}
-	public void setPixelsInsideWrap( int setting ){
-		setIntProperty( getHandle(), "pixels_inside_wrap", setting );
-	}
-	public void setEditable( boolean editable ){
-		setBooleanProperty( getHandle(), "editable", editable );
-	}
-	public void setStrikethrough( boolean strikethrough ){
-		setBooleanProperty( getHandle(), "strikethrough", strikethrough );
-	}
-	public void setWeight( Weight weight ){
-		setIntProperty( getHandle(), "weight", weight.getValue() );
-	}
-	public void setWrapMode( WrapMode mode ){
-		setIntProperty( getHandle(), "wrap_mode", mode.getValue() );
-	}
-	public void setLeftMargin( int margin ){
-		setIntProperty( getHandle(), "left-margin", margin );
-	}
-	public void setRightMargin( int margin ){
-		setIntProperty( getHandle(), "right-margin", margin );
-	}
-	public void setRise( int rise ){
-		setIntProperty( getHandle(), "rise", rise );
-	}
-	public void setIndent( int indent ){
-		setIntProperty( getHandle(), "indent", indent );
-	}
-	public void setUnderline( Underline underline ){
-		setIntProperty( getHandle(), "underline", underline.getValue() );
-	}
-	public void setJustification( Justification justification ){
-		setIntProperty( getHandle(), "justification", justification.getValue() );
-	}
-	public void setStyle( Style  style){
-		setIntProperty( getHandle(), "style", style.getValue() );
+
+	/**
+	 * Bitmap to use as a mask when drawing the text background.
+	 * @param stipple
+	 */
+	public void setBackgroundStipple(Pixmap stipple) {
+		setPixmapProperty(getHandle(), "background-stipple", stipple.getHandle());
 	}
+	
+	/**
+	 * Text direction, e.g. right-to-left or left-to-right.
+	 * @param direction
+	 */
 	public void setDirection( TextDirection direction){
 		setIntProperty( getHandle(), "direction", direction.getValue() );
 	}
-	public void setScale( Scale scale){
+
+	/**
+	 * Whether the text can be modified by the user.
+	 * @param editable
+	 */
+	public void setEditable( boolean editable ){
+		setBooleanProperty( getHandle(), "editable", editable );
+	}
+
+	/**
+	 * Name of the font family, e.g. Sans, Helvetica, Times, Monospace.
+	 * @param family
+	 */
+	public void setFamily( String family ){
+		setStringProperty( getHandle(), "family", family);
+	}
+	
+	/**
+	 * Font description as a string, e.g. "Sans Italic 12".
+	 * @param font
+	 */
+	public void setFont(String font) {
+		setStringProperty( getHandle(), "font", font );
+	}
+
+	/**
+	 * Font description as a FontDescription.
+	 * @param fontDesc
+	 */
+	public void setFontDescription( FontDescription fontDesc ) {
+		setFontDesc( getHandle(), fontDesc.getHandle() );
+	}
+	
+	/**
+	 * Foreground color as a string
+	 * @param foreground
+	 */
+	public void setForeground( String foreground ){
+		setStringProperty( getHandle(), "foreground", foreground );
+	}
+	
+	/**
+	 * Bitmap to use as a mask when drawing the text foreground.
+	 * @param stipple
+	 */
+	public void setForegroundStipple(Pixmap stipple) {
+		setPixmapProperty( getHandle(), "foreground-stipple", stipple.getHandle() );
+	}
+
+	/**
+	 * Amount to indent the paragraph, in pixels.
+	 * @param indent
+	 */
+	public void setIndent( int indent ){
+		setIntProperty( getHandle(), "indent", indent );
+	}
+	
+	/**
+	 * Left, right, or center justification.
+	 * @param justification
+	 */
+	public void setJustification( Justification justification ){
+		setIntProperty( getHandle(), "justification", justification.getValue() );
+	}
+	
+	/**
+	 * The language this text is in, as an ISO code. Pango can use this 
+	 * as a hint when rendering the text. If not set, an appropriate 
+	 * default will be used.
+	 * @param language
+	 */
+	public void setLanguage( String language ) {
+		setStringProperty( getHandle(), "language", language );
+	}
+
+	/**
+	 * Width of the left margin in pixels.
+	 * @param margin
+	 */
+	public void setLeftMargin( int margin ){
+		setIntProperty( getHandle(), "left-margin", margin );
+	}
+
+	/**
+	 * Pixels of blank space above paragraphs.
+	 * @param setting
+	 */
+	public void setPixelsAboveLines( int setting ){
+		setIntProperty( getHandle(), "pixels_above_lines", setting );
+	}
+
+	/**
+	 * Pixels of blank space below paragraphs.
+	 * @param setting
+	 */
+	public void setPixelsBelowLines( int setting ){
+		setIntProperty( getHandle(), "pixels_below_lines", setting );
+	}
+
+	/**
+	 * Pixels of blank space between wrapped lines in a paragraph.
+	 * @param setting
+	 */
+	public void setPixelsInsideWrap( int setting ){
+		setIntProperty( getHandle(), "pixels_inside_wrap", setting );
+	}
+
+	/**
+	 * Width of the right margin in pixels.
+	 * @param margin
+	 */
+	public void setRightMargin( int margin ){
+		setIntProperty( getHandle(), "right-margin", margin );
+	}
+
+	/**
+	 * Offset of text above the baseline (below the baseline if rise 
+	 * is negative) in pixels.
+	 * @param rise
+	 */
+	public void setRise( int rise ){
+		setIntProperty( getHandle(), "rise", rise );
+	}
+
+	/**
+	 * Font size as a scale factor relative to the default font size. 
+	 * This properly adapts to theme changes etc. so is recommended. 
+	 * @param scale
+	 */
+	public void setScale( Scale scale ){
 		setDoubleProperty( getHandle(), "scale", scale.getValue() );
 	}
-//		"background"           gchararray           : Write
+
+	/**
+	 * Font size in Pango units.
+	 * @param size
+	 */
+	public void setSize( int size ){
+		setIntProperty( getHandle(), "size", size * 1024);
+	}
+
+	/**
+	 * Font size in points.
+	 * @param points
+	 */
+	public void setSizePoints( double points ) {
+		setDoubleProperty( getHandle(), "size-points", points );
+	}
+
+	/**
+	 * Font stretch as a Stretch.
+	 * @param stretch
+	 */
+	public void setStretch( Stretch stretch ) {
+		setIntProperty( getHandle(), "stretch", stretch.getValue() );
+	}
+	
+	/**
+	 * Whether to strike through the text.
+	 * @param strikethrough
+	 */
+	public void setStrikethrough( boolean strikethrough ){
+		setBooleanProperty( getHandle(), "strikethrough", strikethrough );
+	}
+
+	/**
+	 * Font Style
+	 * @param style
+	 */
+	public void setStyle( Style  style ){
+		setIntProperty( getHandle(), "style", style.getValue() );
+	}
+	
+	/**
+	 * Custom tabs for this text.
+	 * @param tabs
+	 */
+	public void setTabs( TabArray tabs ) {
+		setTabs( getHandle(), tabs.getHandle() );
+	}
+
+	/**
+	 * Style of underline for this text.
+	 * @param underline
+	 */
+	public void setUnderline( Underline underline ){
+		setIntProperty( getHandle(), "underline", underline.getValue() );
+	}
+
+	/**
+	 * Font variant as a Variant.
+	 * @param variant
+	 */
+	public void setVariant( Variant variant ) {
+		setIntProperty( getHandle(), "variant", variant.getValue() );
+	}
+
+	/**
+	 * Font weight as an integer, see predefined values in Weight
+	 * @param weight
+	 */
+	public void setWeight( Weight weight ){
+		setIntProperty( getHandle(), "weight", weight.getValue() );
+	}
+	
+	/**
+	 * Whether to wrap lines never, at word boundaries, or at character 
+	 * boundaries.
+	 * @param mode
+	 */
+	public void setWrapMode( WrapMode mode ){
+		setIntProperty( getHandle(), "wrap_mode", mode.getValue() );
+	}
+	
+	
+// "background"           gchararray           : Write
 //  "background-full-height" gboolean             : Read / Write
 //  "background-full-height-set" gboolean             : Read / Write
 //  "background-gdk"       GdkColor             : Read / Write
@@ -166,6 +366,7 @@ public class TextTag extends GObject
 //  "rise-set"             gboolean             : Read / Write
 //  "scale"                gdouble              : Read / Write
 //  "scale-set"            gboolean             : Read / Write
+//  "size"				 gint				  : Read / Write
 //  "size-points"          gdouble              : Read / Write
 //  "size-set"             gboolean             : Read / Write
 //  "stretch"              PangoStretch         : Read / Write
@@ -180,6 +381,7 @@ public class TextTag extends GObject
 //  "underline-set"        gboolean             : Read / Write
 //  "variant"              PangoVariant         : Read / Write
 //  "variant-set"          gboolean             : Read / Write
+//  "weight"				 gint				  : Read / Write
 //  "weight-set"           gboolean             : Read / Write
 //  "wrap-mode"            GtkWrapMode          : Read / Write
 //  "wrap-mode-set"        gboolean             : Read / Write
@@ -187,39 +389,43 @@ public class TextTag extends GObject
 
 
     native static final protected String getName (Handle cptr);
-    native static final protected boolean getBgColorSet (Handle cptr);
-    native static final protected boolean getBgStippleSet (Handle cptr);
-    native static final protected boolean getFgColorSet (Handle cptr);
-    native static final protected boolean getScaleSet (Handle cptr);
-    native static final protected boolean getFgStippleSet (Handle cptr);
-    native static final protected boolean getJustificationSet (Handle cptr);
-    native static final protected boolean getLeftMarginSet (Handle cptr);
-    native static final protected boolean getIndentSet (Handle cptr);
-    native static final protected boolean getRiseSet (Handle cptr);
-    native static final protected boolean getStrikethroughSet (Handle cptr);
-    native static final protected boolean getRightMarginSet (Handle cptr);
-    native static final protected boolean getPixelsAboveLinesSet (Handle cptr);
-    native static final protected boolean getPixelsBelowLinesSet (Handle cptr);
-    native static final protected boolean getPixelsInsideWrapSet (Handle cptr);
-    native static final protected boolean getTabsSet (Handle cptr);
-    native static final protected boolean getUnderlineSet (Handle cptr);
-    native static final protected boolean getWrapModeSet (Handle cptr);
-    native static final protected boolean getBgFullHeightSet (Handle cptr);
-    native static final protected boolean getInvisibleSet (Handle cptr);
-    native static final protected boolean getEditableSet (Handle cptr);
-    native static final protected boolean getLanguageSet (Handle cptr);
-    native static final protected boolean getPad1 (Handle cptr);
-    native static final protected boolean getPad2 (Handle cptr);
-    native static final protected boolean getPad3 (Handle cptr);
+//    native static final protected boolean getBgColorSet (Handle cptr);
+//    native static final protected boolean getBgStippleSet (Handle cptr);
+//    native static final protected boolean getFgColorSet (Handle cptr);
+//    native static final protected boolean getScaleSet (Handle cptr);
+//    native static final protected boolean getFgStippleSet (Handle cptr);
+//    native static final protected boolean getJustificationSet (Handle cptr);
+//    native static final protected boolean getLeftMarginSet (Handle cptr);
+//    native static final protected boolean getIndentSet (Handle cptr);
+//    native static final protected boolean getRiseSet (Handle cptr);
+//    native static final protected boolean getStrikethroughSet (Handle cptr);
+//    native static final protected boolean getRightMarginSet (Handle cptr);
+//    native static final protected boolean getPixelsAboveLinesSet (Handle cptr);
+//    native static final protected boolean getPixelsBelowLinesSet (Handle cptr);
+//    native static final protected boolean getPixelsInsideWrapSet (Handle cptr);
+//    native static final protected boolean getTabsSet (Handle cptr);
+//    native static final protected boolean getUnderlineSet (Handle cptr);
+//    native static final protected boolean getWrapModeSet (Handle cptr);
+//    native static final protected boolean getBgFullHeightSet (Handle cptr);
+//    native static final protected boolean getInvisibleSet (Handle cptr);
+//    native static final protected boolean getEditableSet (Handle cptr);
+//    native static final protected boolean getLanguageSet (Handle cptr);
+//    native static final protected boolean getPad1 (Handle cptr);
+//    native static final protected boolean getPad2 (Handle cptr);
+//    native static final protected boolean getPad3 (Handle cptr);
     native static final protected int gtk_text_tag_get_type ();
     native static final protected Handle gtk_text_tag_new (String name);
     native static final protected int gtk_text_tag_get_priority (Handle tag);
     native static final protected void gtk_text_tag_set_priority (Handle tag, int priority);
-    native static final protected boolean gtk_text_tag_event (Handle tag, int eventObject, int event, 
-            Handle iter);
+//    native static final protected boolean gtk_text_tag_event (Handle tag, int eventObject, int event, 
+//            Handle iter);
 	native static final protected void setStringProperty( Handle handle, String property, String setting );
 	native static final protected void setBooleanProperty( Handle handle, String property, boolean setting );
 	native static final protected void setIntProperty( Handle handle, String property, int setting );
 	native static final protected void setDoubleProperty( Handle handle, String property, double setting );
+	// TODO: implement this method
+	native static final protected void setPixmapProperty( Handle handle, String property, Handle pixmap );
+	native static final protected void setTabs( Handle handle, Handle tabArray );
+	native static final protected void setFontDesc( Handle handle, Handle fontDesc );
 }
 
