@@ -9,9 +9,11 @@
 
 package org.gnu.gtk;
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
+
 public class ToolTipsData extends Boxed 
 {
-	ToolTipsData(int handle) {
+	ToolTipsData(Handle handle) {
 		this.handle = handle;
 	}
 	
@@ -26,15 +28,10 @@ public class ToolTipsData extends Boxed
 	public String getTipText() {
 		return getTipText(handle);
 	}
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
-    native static final protected int getToolTip (int cptr);
-    native static final protected int getWidget (int cptr);
-    native static final protected String getTipText (int cptr);
-    native static final protected int gtk_tooltips_data_get (int widget);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+
+    native static final protected Handle getToolTip (Handle cptr);
+    native static final protected Handle getWidget (Handle cptr);
+    native static final protected String getTipText (Handle cptr);
+    native static final protected Handle gtk_tooltips_data_get (Handle widget);
 }
 
