@@ -48,7 +48,7 @@ public class TreeModelSort extends TreeModel implements TreeSortable {
      * Return the underlying data model.
      */
     public TreeModel getModel() {
-        return (TreeModel)retrieveGObject(gtk_tree_model_sort_get_model(getHandle()));
+        return (TreeModel)getGObjectFromHandle(gtk_tree_model_sort_get_model(getHandle()));
     }
 
     /**
@@ -97,7 +97,7 @@ public class TreeModelSort extends TreeModel implements TreeSortable {
                                   Handle bIter, int col ) {
         TreeIterComparison method = TreeSortableHelper.getMethod( this, col );
         if ( method != null ) {
-            TreeModel mdl = (TreeModel)retrieveGObject( model );
+            TreeModel mdl = (TreeModel)getGObjectFromHandle( model );
             TreeIter a = new TreeIter( aIter, mdl );
             TreeIter b = new TreeIter( bIter, mdl );
             return method.compareTreeIters( mdl, a, b );
