@@ -64,7 +64,7 @@ public class TreeSelection extends GObject {
 	/** This is called from the jni code to operate the foreach method */
 	private void doEach(Handle model, Handle path, Handle iter) {
 		TreeModel m; 
-		GObject obj = retrieveGObject(model);
+		GObject obj = getGObjectFromHandle(model);
 		if (null != obj)
 			m = (TreeModel)obj;
 		else
@@ -92,7 +92,7 @@ public class TreeSelection extends GObject {
 	 */
 	public TreeView getTreeView() {
 	    Handle hndl = gtk_tree_selection_get_tree_view(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TreeView)obj;
 		return new TreeView(hndl);
