@@ -10,6 +10,7 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
 import org.gnu.gtk.Widget;
 
 /**
@@ -21,7 +22,7 @@ public class HandleBoxEvent extends GtkEvent {
 	
 	private Widget widget;
 
-	public static class Type extends GtkEventType {
+	public static class Type extends EventType {
 		private Type(int id, String name) {
 			super(id, name);
 		}
@@ -35,7 +36,7 @@ public class HandleBoxEvent extends GtkEvent {
 	 * @param source
 	 * @param type
 	 */
-	public HandleBoxEvent(Object source, GtkEventType type) {
+	public HandleBoxEvent(Object source, EventType type) {
 		super(source, type);
 	}
 
