@@ -21,8 +21,6 @@ import org.gnu.gdk.ScrollDirection;
 import org.gnu.glib.EventType;
 
 /**
- * @author Jeffrey S. Morgan
- *
  * This event represents mouse events.
  * 
  * @see MouseListener
@@ -61,12 +59,19 @@ public class MouseEvent extends GtkEvent {
 		public static final Type WHEEL_SCROLL = new Type(5, "WHEEL_SCROLL");
 	}
 		
-	/**
+	/*
 	 * Used to identify which button was pressed.
 	 */
 	public static final int BUTTON1 = 1;
 	public static final int BUTTON2 = 2;
 	public static final int BUTTON3 = 3;
+	
+	/*
+	 * Used to identify number of clicks
+	 */
+	public static final int SINGLE_CLICK = 4;
+	public static final int DOUBLE_CLICK = 5;
+	public static final int TRIPPLE_CLICK = 6;
 
 	/**
 	 * Identifies what button was pressed for the BUTTON_PRESS or 
@@ -86,6 +91,11 @@ public class MouseEvent extends GtkEvent {
 	 */
 	private double y = 0;
 	
+	/**
+	 * Indicates single, double, or tripple clicks
+	 */
+	private int clickType = -1;
+	
 	/**
 	 * Indicates which way the mouse wheel scrolled for a WHEEL_SCROLL event.
 	 */
@@ -99,6 +109,7 @@ public class MouseEvent extends GtkEvent {
 		this.x = gdkEvent.getX();
 		this.y = gdkEvent.getY();
 		this.buttonPressed = gdkEvent.getButton();
+		this.clickType = gdkEvent.getType();
 	}
 
 	/**
