@@ -296,6 +296,18 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Visual_gdk_1visual_1get_1best_1with_1
 }
 
 
+/*
+ * Class:     org_gnu_gdk_Visual
+ * Method:    gdk_visual_get_screen
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Visual_gdk_1visual_1get_1screen
+  (JNIEnv *env, jclass cls, jobject visual)
+{
+	GdkVisual *visual_g = (GdkVisual *)getPointerFromHandle(env, visual);
+	return getHandleFromPointer(env, gdk_visual_get_screen(visual_g));
+}
+
+
 #ifdef __cplusplus
 }
 
