@@ -397,7 +397,7 @@ jg_static_cbdata_new(JNIEnv *env,
   jthrowable exc;
   jclass Exception;
   
-  gtko = (GObject*)getPointerFromHandle(env, obj);
+  gtko = (GObject*)getPointerFromJavaGObject(env, obj);
   sigid = g_signal_lookup(signame, G_OBJECT_TYPE(gtko));
   g_assert(sigid > 0);
   g_signal_query(sigid, &siginfo);
@@ -509,7 +509,7 @@ static jint create_static_callback(JNIEnv *env,
   GClosure *closure;
   jclass Exception;
   
-  go = (GObject*)getPointerFromHandle(env, obj);
+  go = (GObject*)getPointerFromJavaGObject(env, obj);
   signame = (*env)->GetStringUTFChars(env, sigstring, NULL);
   sigfunc = (*env)->GetStringUTFChars(env, func, NULL);
   
@@ -520,7 +520,6 @@ static jint create_static_callback(JNIEnv *env,
     (* env)->ThrowNew(env, Exception, "" );
     return 0;
   }
-
   cbdata = jg_static_cbdata_new(env, obj, cbrecv, data, signame, sigfunc);
 
   if (cbdata == NULL)
@@ -528,7 +527,7 @@ static jint create_static_callback(JNIEnv *env,
     
   closure = jg_closure_new();
   ((JGClosure *)closure)->cbdata = cbdata;
-  retval = g_signal_connect_closure_by_id(getPointerFromHandle(env, obj),
+  retval = g_signal_connect_closure_by_id(getPointerFromJavaGObject(env, obj),
 					  sigid,
 					  detail,
 					  closure,
