@@ -217,6 +217,78 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Gtk_gtk_1type_1from_1name (JNIEnv *en
 	return retval;
 }
 
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_Gtk_gtk_1true
+(JNIEnv *env, jclass cls)
+{
+    return (jboolean)gtk_true();
+}
+
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_Gtk_gtk_1false
+(JNIEnv *env, jclass cls)
+{
+    return (jboolean)gtk_false();
+}
+
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_Gtk_gtk_1main_1iteration_1do
+(JNIEnv *env, jclass cls, jboolean blocking)
+{
+    gboolean blocking_g = (gboolean)blocking;
+    return (jboolean)gtk_main_iteration_do(blocking_g);
+}
+
+static gint gtkKeySnoopFunc(GtkWidget *grab_widget, GdkEventKey *event,
+                            gpointer data) {
+    JGFuncCallbackRef *ref = (JGFuncCallbackRef*) data;
+    return (gint)
+        (* ref->env)->CallStaticBooleanMethod(ref->env, 
+                                              ref->cls, 
+                                              ref->methodID,
+                                              getHandleFromPointer(ref->env, 
+                                                                   grab_widget),
+                                              getHandleFromPointer(ref->env, 
+                                                                   event));
+}
+
+JNIEXPORT jint JNICALL Java_org_gnu_gtk_Gtk_gtk_1key_1snooper_1install
+(JNIEnv *env, jclass cls, jobject snooper, jstring callback)
+{
+    JGFuncCallbackRef *ref = g_new( JGFuncCallbackRef, 1 );
+    ref->env = env;
+    ref->obj = NULL;
+    ref->cls = cls;
+
+    const char *funcname = (*env)->GetStringUTFChars(env, callback, NULL);
+    // Get method id for the callback method name.
+    ref->methodID = 
+        (*env)->GetStaticMethodID(env, cls,
+                                  funcname, 
+                                  "(Lorg/gnu/glib/Handle;Lorg/gnu/glib/Handle;)Z" );
+    if ( ref->methodID == NULL ) {
+        (*env)->ReleaseStringUTFChars(env, callback, funcname);
+        g_free( ref );
+        // Error!  Throw exception!
+        return -1;
+    }
+    (*env)->ReleaseStringUTFChars(env, callback, funcname);
+
+    return (jint)gtk_key_snooper_install(gtkKeySnoopFunc, ref);
+}
+
+JNIEXPORT void JNICALL Java_org_gnu_gtk_Gtk_gtk_1key_1snooper_1remove
+(JNIEnv *env, jclass cls, jint snooper_handler_id)
+{
+    guint snooper_handler_id_g = (guint)snooper_handler_id;
+    gtk_key_snooper_remove(snooper_handler_id_g);
+}
+
+JNIEXPORT void JNICALL Java_org_gnu_gtk_Gtk_gtk_1propagate_1event
+(JNIEnv *env, jclass cls, jobject widget, jobject event)
+{
+    GtkWidget * widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
+    GdkEvent * event_g = (GdkEvent *)getPointerFromHandle(env, event);
+    gtk_propagate_event(widget_g, event_g);
+}
+
 #ifdef __cplusplus
 }
 
