@@ -1048,7 +1048,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1modify_1fg (JNIEnv *
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GtkStateType state_g = (GtkStateType) state;
-    GdkColor *color_g = (GdkColor *)color;
+    GdkColor *color_g = (GdkColor *)getPointerFromHandle(env, color);
     gtk_widget_modify_fg (widget_g, state_g, color_g);
 }
 
@@ -1061,7 +1061,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1modify_1bg (JNIEnv *
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GtkStateType state_g = (GtkStateType) state;
-    GdkColor *color_g = (GdkColor *)color;
+    GdkColor *color_g = (GdkColor *)getPointerFromHandle(env, color);
     gtk_widget_modify_bg (widget_g, state_g, color_g);
 }
 
@@ -1074,7 +1074,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1modify_1text (JNIEnv
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GtkStateType state_g = (GtkStateType) state;
-    GdkColor *color_g = (GdkColor *)color;
+    GdkColor *color_g = (GdkColor *)getPointerFromHandle(env, color);
     gtk_widget_modify_text (widget_g, state_g, color_g);
 }
 
@@ -1087,7 +1087,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1modify_1base (JNIEnv
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GtkStateType state_g = (GtkStateType) state;
-    GdkColor *color_g = (GdkColor *)color;
+    GdkColor *color_g = (GdkColor *)getPointerFromHandle(env, color);
     gtk_widget_modify_base (widget_g, state_g, color_g);
 }
 
@@ -1560,20 +1560,9 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1drag_1dest_1set(JNIEnv *env,
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GtkDestDefaults flags_g = (GtkDestDefaults)flags;
     GdkDragAction actions_g = (GdkDragAction)actions;
-
-    GtkTargetEntry** entries;
-    jsize len;
-    int index;
-    len = (*env)->GetArrayLength(env, targets);
-    entries = g_malloc(sizeof(GtkTargetEntry*)*len);
-    for (index = 0; index < len; index++)
-        entries[index] = 
-            (GtkTargetEntry*)
-            getPointerFromHandle(env, (*env)->GetObjectArrayElement(env, 
-                                                                    targets, 
-                                                                    index));
-
-    gtk_drag_dest_set(widget_g, flags_g, *entries, len, actions_g);
+    GtkTargetEntry* entries = (GtkTargetEntry*)getPointerArrayFromHandles(env, targets);
+    jsize len = (*env)->GetArrayLength(env, targets);
+    gtk_drag_dest_set(widget_g, flags_g, entries, len, actions_g);
 }
 
 /*
